
#ifndef _GDFONTT_H_
#define _GDFONTT_H_ 1

/*
	This is a header file for gd font, generated using
	bdftogd version 0.60 by Jan Pazdziora, adelton@fi.muni.cz
	from bdf font
	-Gemini-Fixed-Medium-R-Normal--10-100-75-75-C-60-KOI8-U
	at Tue Jan 29 07:24:08 2002.
	The original bdf was holding following copyright:
	"Copyright (C) 1994 Cronyx Ltd."
 */


#include "gd.h"

extern gdFontPtr gdFontTiny;

#endif

